<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CHARSET","windows-1256");
define("_SEARCH","");
define("_LOGIN","");
define("_WRITES","");
define("_POSTEDON"," ");
define("_NICKNAME","");
define("_PASSWORD"," ");
define("_WELCOMETO","");
define("_EDIT","");
define("_DELETE","");
define("_POSTEDBY"," ");
define("_READS","");
define("_GOBACK","[ <a href=\"javascript:history.go(-1)\"></a> ]");
define("_COMMENTS","");
define("_PASTARTICLES"," ");
define("_OLDERARTICLES"," ");
define("_BY","");
define("_ON","");
define("_LOGOUT","");
define("_WAITINGCONT"," ");
define("_SUBMISSIONS","");
define("_WREVIEWS"," ");
define("_WLINKS"," ");
define("_EPHEMERIDS"," ");
define("_ONEDAY","   ...");
define("_ASREGISTERED","  Ͽ  <a href=\"modules.php?name=Your_Account\"></a>.      ,      .");
define("_MENUFOR"," ");
define("_NOBIGSTORY","    .");
define("_BIGSTORY","   :");
define("_SURVEY","");
define("_POLLS","");
define("_PCOMMENTS",":");
define("_RESULTS","");
define("_HREADMORE"," ...");
define("_CURRENTLY"," ,");
define("_GUESTS","/");
define("_MEMBERS","/  .");
define("_YOUARELOGGED","  ");
define("_YOUHAVE"," ");
define("_PRIVATEMSG"," .");
define("_YOUAREANON","   .     <a href=\"modules.php?name=Your_Account\"></a>");
define("_NOTE",":");
define("_ADMIN"," :");
define("_WERECEIVED"," ");
define("_PAGESVIEWS","  ");
define("_TOPIC","");
define("_UDOWNLOADS","");
define("_VOTE","");
define("_VOTES","");
define("_MVIEWADMIN",":  ");
define("_MVIEWUSERS",":   ");
define("_MVIEWANON",":    ");
define("_MVIEWALL",":  ");
define("_EXPIRELESSHOUR"," :  ");
define("_EXPIREIN"," ");
define("_HTTPREFERERS"," ");
define("_UNLIMITED"," ");
define("_HOURS","");
define("_RSSPROBLEM","       ");
define("_SELECTLANGUAGE"," ");
define("_SELECTGUILANG","  :");
define("_NONE"," ");
define("_BLOCKPROBLEM","<center>    .</center>");
define("_BLOCKPROBLEM2","<center>     .</center>");
define("_MODULENOTACTIVE","   !");
define("_NOACTIVEMODULES","  ");
define("_FORADMINTESTS","(   )");
define("_BBFORUMS","");
define("_ACCESSDENIED", "  ");
define("_RESTRICTEDAREA", "     .");
define("_MODULEUSERS", "     <i>  </i><br><br>   <a href=\"user.php?op=new_user\"></a>,  <br>    .<br><br>");
define("_MODULESADMINS", "      <i> </i><br><br>");
define("_HOME"," ");
define("_HOMEPROBLEM"," :    !!!");
define("_ADDAHOME","     ");
define("_HOMEPROBLEMUSER","     .    .");
define("_MORENEWS","    ");
define("_ALLCATEGORIES"," ");
define("_DATESTRING","%A, %B %d");
define("_DATESTRING2","%A, %B %d");
define("_DATE","");
define("_HOUR","");
define("_UMONTH","");
define("_YEAR","");
define("_JANUARY","");
define("_FEBRUARY","");
define("_MARCH","");
define("_APRIL","");
define("_MAY","");
define("_JUNE","");
define("_JULY","");
define("_AUGUST","");
define("_SEPTEMBER","");
define("_OCTOBER","");
define("_NOVEMBER","");
define("_DECEMBER","");
define("_BWEL","");
define("_BPM"," ");
define("_BUNREAD"," ");
define("_BREAD","");
define("_BMEMP","");
define("_BLATEST","");
define("_BTD"," ");
define("_BYD"," ");
define("_BOVER","");
define("_BVISIT"," ");
define("_BVIS","");
define("_BMEM","");
define("_BTT","");
define("_BON"," ");
define("_BREG","");
define("_BROADCAST","  ");
define("_BROADCASTFROM","  ");
define("_TURNOFFMSG","  ");
define("_JOURNAL","");
define("_READMYJOURNAL"," ");
define("_ADD","");
define("_YES","");
define("_NO","");
define("_INVISIBLEMODULES","  ");
define("_ACTIVEBUTNOTSEE","(   )");
define("_THISISAUTOMATED","          .");
define("_THERESULTS","   :");
define("_TOTALIMPRESSIONS"," :");
define("_CLICKSRECEIVED"," :");
define("_IMAGEURL"," ");
define("_CLICKURL"," :");
define("_ALTERNATETEXT"," :");
define("_HOPEYOULIKED","           .");
define("_THANKSUPPORT","  ");
define("_TEAM"," ");
define("_BANNERSFINNISHED"," ");
define("_MODREQLINKS"," ");
define("_BROKENLINKS","  ");
define("_MODREQDOWN"," ");
define("_BROKENDOWN","  ");
define("_PAGEGENERATION"," :");
define("_SECONDS","");

/*****************************************************/
/* Function to translate Datestrings                 */
/*****************************************************/

function translate($phrase) {
    switch($phrase) {
	case "xdatestring":	$tmp = "%A, %B %d @ %T %Z"; break;
	case "linksdatestring":	$tmp = "%d-%b-%Y"; break;
	case "xdatestring2":	$tmp = "%A, %B %d"; break;
	default:		$tmp = "$phrase"; break;
    }
    return $tmp;
}

?>